[Bf-blender-cvs] [f5604af] master: Cleanup: use BM_mesh_* prefix for BMesh functions

Campbell Barton noreply at git.blender.org
Thu Jan 14 03:08:55 CET 2016


Commit: f5604af464cd2e2cbb271378df2827cbe6eaffe3
Author: Campbell Barton
Date:   Thu Jan 14 13:00:11 2016 +1100
Branches: master
https://developer.blender.org/rBf5604af464cd2e2cbb271378df2827cbe6eaffe3

Cleanup: use BM_mesh_* prefix for BMesh functions

===================================================================

M	source/blender/blenkernel/intern/editmesh.c
M	source/blender/bmesh/intern/bmesh_polygon.c
M	source/blender/bmesh/intern/bmesh_polygon.h
M	source/blender/modifiers/intern/MOD_boolean.c
M	source/blender/python/bmesh/bmesh_py_types.c
M	source/blender/python/mathutils/mathutils_bvhtree.c

===================================================================

diff --git a/source/blender/blenkernel/intern/editmesh.c b/source/blender/blenkernel/intern/editmesh.c
index 87a5c6f..fea3c24 100644
--- a/source/blender/blenkernel/intern/editmesh.c
+++ b/source/blender/blenkernel/intern/editmesh.c
@@ -142,7 +142,7 @@ static void editmesh_tessface_calc_intern(BMEditMesh *em)
 	em->looptris = looptris;
 
 	/* after allocating the em->looptris, we're ready to tessellate */
-	BM_bmesh_calc_tessellation(em->bm, em->looptris, &em->tottri);
+	BM_mesh_calc_tessellation(em->bm, em->looptris, &em->tottri);
 
 }
 
diff --git a/source/blender/bmesh/intern/bmesh_polygon.h b/source/blender/bmesh/intern/bmesh_polygon.h
index c84f479..a1d1710 100644
--- a/source/blender/bmesh/intern/bmesh_polygon.h
+++ b/source/blender/bmesh/intern/bmesh_polygon.h
@@ -32,7 +32,7 @@ struct Heap;
 
 #include "BLI_compiler_attrs.h"
 
-void  BM_bmesh_calc_tessellation(BMesh *bm, BMLoop *(*looptris)[3], int *r_looptris_tot);
+void  BM_mesh_calc_tessellation(BMesh *bm, BMLoop *(*looptris)[3], int *r_looptris_tot);
 
 void  BM_face_calc_tessellation(
         const BMFace *f, const bool use_fixed_quad,
diff --git a/source/blender/modifiers/intern/MOD_boolean.c b/source/blender/modifiers/intern/MOD_boolean.c
index 750fb47..03ff902 100644
--- a/source/blender/modifiers/intern/MOD_boolean.c
+++ b/source/blender/modifiers/intern/MOD_boolean.c
@@ -234,7 +234,7 @@ static DerivedMesh *applyModifier_bmesh(
 
 				looptris = MEM_mallocN(sizeof(*looptris) * looptris_tot, __func__);
 
-				BM_bmesh_calc_tessellation(bm, looptris, &tottri);
+				BM_mesh_calc_tessellation(bm, looptris, &tottri);
 
 				/* postpone this until after tessellating
 				 * so we can use the original normals before the vertex are moved */
diff --git a/source/blender/python/bmesh/bmesh_py_types.c b/source/blender/python/bmesh/bmesh_py_types.c
index fc25a79..833e8e3 100644
--- a/source/blender/python/bmesh/bmesh_py_types.c
+++ b/source/blender/python/bmesh/bmesh_py_types.c
@@ -1257,7 +1257,7 @@ static PyObject *bpy_bmesh_calc_tessface(BPy_BMElem *self)
 	looptris_tot = poly_to_tri_count(bm->totface, bm->totloop);
 	looptris = PyMem_MALLOC(sizeof(*looptris) * looptris_tot);
 
-	BM_bmesh_calc_tessellation(bm, looptris, &tottri);
+	BM_mesh_calc_tessellation(bm, looptris, &tottri);
 
 	ret = PyList_New(tottri);
 	for (i = 0; i < tottri; i++) {
diff --git a/source/blender/python/mathutils/mathutils_bvhtree.c b/source/blender/python/mathutils/mathutils_bvhtree.c
index b3b9d4a..20baf6c 100644
--- a/source/blender/python/mathutils/mathutils_bvhtree.c
+++ b/source/blender/python/mathutils/mathutils_bvhtree.c
@@ -894,7 +894,7 @@ static PyObject *C_BVHTree_FromBMesh(PyObject *UNUSED(cls), PyObject *args, PyOb
 
 		looptris = MEM_mallocN(sizeof(*looptris) * (size_t)tris_len, __func__);
 
-		BM_bmesh_calc_tessellation(bm, looptris, &tris_len_dummy);
+		BM_mesh_calc_tessellation(bm, looptris, &tris_len_dummy);
 		BLI_assert(tris_len_dummy == (int)tris_len);
 	}




More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/bmesh/intern/bmesh_polygon.c b/source/blender/bmesh/intern/bmesh_polygon.c
index 8d8db79..40f6078 100644
--- a/source/blender/bmesh/intern/bmesh_polygon.c
+++ b/source/blender/bmesh/intern/bmesh_polygon.c
@@ -1267,12 +1267,12 @@ void BM_face_as_array_loop_quad(BMFace *f, BMLoop *r_loops[4])
 
 
 /**
  * \brief BM_bmesh_calc_tessellation get the looptris and its number from a certain bmesh
  * \param looptris
  *
  * \note \a looptris  Must be pre-allocated to at least the size of given by: poly_to_tri_count
  */
-void BM_bmesh_calc_tessellation(BMesh *bm, BMLoop *(*looptris)[3], int *r_looptris_tot)
+void BM_mesh_calc_tessellation(BMesh *bm, BMLoop *(*looptris)[3], int *r_looptris_tot)
 {
 	/* use this to avoid locking pthread for _every_ polygon
 	 * and calling the fill function */
@@ -1267,12 +1267,12 @@ void BM_face_as_array_loop_quad(BMFace *f, BMLoop *r_loops[4])
 
 /**
- * \brief BM_bmesh_calc_tessellation get the looptris and its number from a certain bmesh
+ * \brief BM_mesh_calc_tessellation get the looptris and its number from a certain bmesh
  * \param looptris
  *